# Manuel technique

La section suivante détaille les choix et le fonctionnement techniques du module `LcvPrestaConnector`, ainsi que les données prisent en compte.



# Pré-requis techniques

Le module est conçu et développé pour fonctionner avec les versions minimales suivantes des bibliothèques :

- **Prestashop 8.1.7**
- PHP 8.1
- MariaDB 13

*Aucun support ni correctif ne sera fourni pour supporter des versions moins élevées de ces dépendances.*

## Modes de fonctionnement

Le module possède deux modes :

1. le **mode basique** : dans le mode basique, le module synchronise uniquement les stocks, les prix et les promotions en se basant sur la référence fournisseur LCV. 
2. le **mode complet** : dans le mode complet, en plus d'effectuer toutes les actions du mode basique, le module crée et tient les fiches produits à jour pour tous les produits déclarés comme publiés sur le site Internet. Quand une donnée existe sur le backoffice LCV, elle est reportée dans Prestashop à la création ; par la suite, si lors d'une synchronisation la donnée existe déjà sous Prestashop, celle-ci est écrasée par la valeur de LCV en fonction de votre configuration. Les données vitales (♜) sont toujours écrasées dans Prestashop ;

*Note : les données marquées d'une tour (♜) sont des données vitales de classification. Ces données sont toujours écrasées par le module si elles existent sous LCV.*



## Fonctionnement général

Le module répond au fonctionnement suivant :

- à intervalle régulier, il est nécessaire d'appeler la tâche cron présente à l'adresse https://votresite.com/module/lcvprestaconnector/cron ; 
- c'est cette tâche qui va initier la communication entre le site Prestashop et votre backoffice et réaliser les opérations d'importation et d'exportation des données en se connectant aux API de votre backoffice ;
- il est nécessaire d'appeler cette tâche régulièrement ;

Le module est conçu pour avoir un impact minimal sur le *front* du site. 



## Fonctionnalités avancées

### Mise à jour automatique

Le module est doté d'un système de mise à jour automatique. Au moins une fois par jour, lors de l'appel d'une tâche de synchronisation, il se connecte à nos serveurs pour vérifier si une nouvelle version est disponible. Dans un tel cas, il télécharge l'archive ZIP contenant la mise à jour et la déploie dans le répertoire `/updates/lastest`. 

Il informe ensuite Prestashop de la disponibilité de la mise à jour. Les utilisateurs ayant le droit peuvent  alors la déployer comme n'importe quel module depuis le gestionnaire de modules de Prestashop.

La mise à jour de la base de données est effectuée automatiquement lors du prochain appel au module.

Nous vous conseillons de mettre à jour le module régulièrement pour bénéficier d'une meilleure prise en charge de votre backoffice, de nos correctifs de sécurité, de fonctionnement, ainsi que des nouvelles fonctionnalités.

## Données synchronisées

### Produits

Fonctionnement général :

- sur LCV, certaines déclinaisons peuvent être discriminantes (par exemple, la couleur ou la matière), d'autres peuvent être des tailles (longueurs de jambe, bonnets, ...) ;
- chaque couple `{produit - déclinaisons discriminantes}` de LCV qui est marqué pour être sur Internet provoque la création et l'entretien d'un produit sous Prestashop ;
- dans ce produit Prestashop, chaque couple `{article - déclinaisons de taille}` de LCV provoque la création d'une déclinaison unique lorsque celle-ci n'existe pas déjà ;
- **la clé de synchronisation (la donnée utilisée pour reconnaître l'entité) est le code-barre LCV de l'article, injecté dans la référence fournisseur du produit, pour le fournisseur nommé `LCV`.** 

#### Données synchronisées sur le produit

*Quand la donnée n'est pas présente dans la colonne Prestashop, alors c'est que la donnée n'est pas synchronisée.*

| Donnée Prestashop                          | Notes                                                        |
| ------------------------------------------ | ------------------------------------------------------------ |
| Référence produit ♜                        | La référence utilisée est la référence produit sous LCV concaténée aux libellés des déclinaisons discriminantes, séparées par le caractère `/`. |
| Référence fournisseur du fournisseur LCV ♜ | La référence produit LCV, agrégée des références de déclinaisons discriminante est utilisée ici. |
| Nom                                        | —                                                            |
| Marque                                     | —                                                            |
| Taux de taxes (TVA)                        | —                                                            |
| Écotaxe                                    | —                                                            |
| Description                                | —                                                            |
| Description Méta                           | —                                                            |
| Largeur, hauteur, profondeur, poids        | —                                                            |
| Prix de vente de base ♜                    | Le prix de vente de base est le prix le plus bas, toutes déclinaisons et tailles confondues. |
| Caractéristiques                           | Les caractéristiques sont définies par mappages de champs dynamiques dans LCV ; voir la configuration pour plus de détails. |
| Catégories                                 | Les catégories sont définies par mappage des `Rayons` et des `Familles` LCV. |
| Photos                                     | —                                                            |

#### Données synchronisée sur la déclinaison

*Quand la donnée est barrée dans la colonne Prestashop, alors c'est que la donnée n'est pas synchronisée avec cette version du module.*

| Donnée Prestashop                          | Notes                                                        |
| ------------------------------------------ | ------------------------------------------------------------ |
| Référence de la déclinaison ♜              | C'est le code-barre LCV qui est utilisé ici.                 |
| Référence fournisseur du fournisseur LCV ♜ | Le code barre LCV est utilisé ici comme clé de synchronisation. |
| Attributs constituants la déclinaison ♜    | Les déclinaisons non-discriminantes et les tailles LCV sont utilisées pour créer les déclinaisons Prestashop. |
| Prix de vente ♜                            | Prix de vente en boutique.                                   |
| Code barre EAN13                           | Code barre fournisseur sous LCV.                             |
| ~~Emplacement du stock~~                   | Non synchronisé sur cette version.                           |
| Association de photo                       | Le module rétablit les bonnes photos avec les bonnes déclinaisons automatiquement. |



### Marques



### Caractéristiques



### Tailles



### Groupes d'attributs



### Catégories



### Stock (♜)

Le module télécharge les stocks ventilés par point de vente et dépôts dans la table `ps_pc_lcv_stocks` puis les agrège dans la table de Prestashop `ps_stock_available` prévu à cet effet en passant par les objets internes pour déclencher tous les *hooks* du système afin que les modules se basant sur le changement des stocks puissent fonctionner correctement.

Vous pouvez vous appuyer sur la table `ps_pc_lcv_stocks`pour calculer et afficher une disponibilité d'article au magasin dans votre propre module si vous le désirez.

Il est à noter que sur option, est déduit de ces stocks agrégés une quantité minimale de stock de sécurité pour chaque taille.

### Promotions (♜)
