<?php 

namespace PrestaShop\Module\LCVPrestaConnector\Controller;

use ApiPlatform\Core\Bridge\Symfony\Bundle\Test\Response;
use PrestaShop\Module\LCVPrestaConnector\Forms\GrilleType;
use Symfony\Component\HttpFoundation\Request;
use PrestaShop\Module\LCVPrestaConnector\SyncConfiguration;


class ConfigurationAdminController extends AdminController
{   

    /**
     * Obtient la description de la barre d'outils de l'interface d'administration
     */
    private function getAdminLayoutToolBar() : array 
    {
        return [
                'bind' => [
                    'href' =>$this->generateUrl('prestaconnector_configuration') . '&reset-binding=1',
                    'class' => 'btn-outline-secondary',
                    'desc' => 'Déconnecter',
                    'icon' => 'cancel',                    
                ]
        ];
    }

    /**
     * Retourne les variables passées en paramètre enrichies des variables par défaut
     */
    private function addDefaultVars(array $vars) : array
    {
        if (!isset($vars['layoutHeaderToolbarBtn']))
            $vars['layoutHeaderToolbarBtn'] = $this->getAdminLayoutToolBar();

        if (!isset($vars['backoffice']))
            $vars['backoffice'] = $this->module->getBridge()->getId();
        
        return $vars;
    }


    public function grilleDeTaille(Request $request){
     

        $form = $this->createForm(GrilleType::class);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            //$data = $form->getData();
        }
    
        return $form;

    }

    /**
     * Vérifie que le backoffice est bien jumelé ou renvoi null
     */
    public function checkLogin() : \Symfony\Component\HttpFoundation\Response|null
    {
        $loginCfg = $this->module->getCfg()->get(SyncConfiguration::CFG_LOGIN);

        if (empty($loginCfg) || (isset($loginCfg["error"]) && $loginCfg["error"]))
        {
            $specifics = $this->module->getBridge()->getSpecifics();            
            
            return $this->render('@Modules/prestaconnector/views/templates/admin/login.html.twig', [
                'MODULE_NAME' => $this->module->name,
                'BACKOFFICE_NAME' => $this->module->getBridge()->getId(),
                'ADDRESS_LABEL' => $specifics["ADDRESS_LABEL"] ?? "",
                'PREVIOUS_ADDRESS' => $specifics["PREVIOUS_ADDRESS"] ?? "",
                "INITIAL_ERROR" => (isset($loginCfg["error"]) && $loginCfg["error"]) ? $loginCfg["error"] : "Il semble que le module n'est pas encore associé avec votre backoffice.",
            ]);            
        }

        return null;
    }

    public function informationAction(){

        // On vérifie s'il faut réinitialisé le jumelage
        if (isset($_REQUEST["reset-binding"]) && $_REQUEST["reset-binding"])
        {
            // Oui, on réinitialise le jumelage en supprimant la configuration de login
            $cfgLogin = null;
            $this->module->getCfg()->set(SyncConfiguration::CFG_LOGIN, $cfgLogin);
        }

        // Vérifions que le jumelage est déjà fait !
        $bindPage = $this->checkLogin(); if ($bindPage) return $bindPage;
        
        return $this->render('@Modules/prestaconnector/views/templates/admin/information.html.twig', $this->addDefaultVars([]));
    }

    public function optionAction(){
        // Vérifions que le jumelage est déjà fait !
        $bindPage = $this->checkLogin(); if ($bindPage) return $bindPage;
  
        return $this->render('@Modules/prestaconnector/views/templates/admin/option.html.twig', $this->addDefaultVars([
            ]));
    }

    public function commandeAction(){
        // Vérifions que le jumelage est déjà fait !
        $bindPage = $this->checkLogin(); if ($bindPage) return $bindPage;
  
        return $this->render('@Modules/prestaconnector/views/templates/admin/commande.html.twig', [
            'layoutHeaderToolbarBtn' => $this->getAdminLayoutToolBar(), 
        ]);
    }
    public function catalogueAction(Request $request){
        // Vérifions que le jumelage est déjà fait !
        $bindPage = $this->checkLogin(); if ($bindPage) return $bindPage;

        $catalogOption = $this->module->getCfg()->get(SyncConfiguration::CFG_DATA_SYNC);
    
    
  
        return $this->render('@Modules/prestaconnector/views/templates/admin/catalogue.html.twig', $this->addDefaultVars([
            'optionsDesc'=> $this->module->getCfg()->describeSyncConfiguration(),
            'optionsValues'=> $catalogOption
        ]));
    }


   

}